@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '1.53';
+our $VERSION = '1.55';
 
 our ( @RD, @LEAP_SECONDS, %RD_LENGTH );
 
@@ -112,7 +112,7 @@ sub _initialize {
             2012  Jul. 1  +1
             2015  Jul. 1  +1
             2017  Jan. 1  +1
-            )
+        )
     );
 }
 
@@ -134,43 +134,40 @@ DateTime::LeapSecond - leap seconds table and utilities
 
 =head1 VERSION
 
-version 1.53
+version 1.55
 
 =head1 SYNOPSIS
 
-  use DateTime;
-  use DateTime::LeapSecond;
+    use DateTime;
+    use DateTime::LeapSecond;
 
-  print "Leap seconds between years 1990 and 2000 are ";
-  print DateTime::Leapsecond::leap_seconds( $utc_rd_2000 ) -
-        DateTime::Leapsecond::leap_seconds( $utc_rd_1990 );
+    print "Leap seconds between years 1990 and 2000 are ";
+    print DateTime::Leapsecond::leap_seconds($utc_rd_2000)
+        - DateTime::Leapsecond::leap_seconds($utc_rd_1990);
 
 =head1 DESCRIPTION
 
-This module is used to calculate leap seconds for a given Rata Die
-day. It is used when DateTime.pm cannot compile the XS version of
-this code.
+This module is used to calculate leap seconds for a given Rata Die day. It is
+used when L<DateTime> cannot compile the XS version of this code.
 
-This library is known to be accurate for dates until Jun 2017.
+This library is known to be accurate for dates until Jun 2020.
 
-There are no leap seconds before 1972, because that's the year this
-system was implemented.
+There are no leap seconds before 1972, because that's the year this system was
+implemented.
 
 =over 4
 
-=item * leap_seconds( $rd )
+=item * leap_seconds($rd)
 
 Returns the number of accumulated leap seconds for a given day.
 
-=item * extra_seconds( $rd )
+=item * extra_seconds($rd)
 
-Returns the number of leap seconds for a given day,
-in the range -2 .. 2.
+Returns the number of leap seconds for a given day, in the range -2 .. 2.
 
-=item * day_length( $rd )
+=item * day_length($rd)
 
-Returns the number of seconds for a given day,
-in the range 86398 .. 86402.
+Returns the number of seconds for a given day, in the range 86398 .. 86402.
 
 =back
 
@@ -178,8 +175,6 @@ in the range 86398 .. 86402.
 
 L<http://hpiers.obspm.fr/eop-pc/earthor/utc/leapsecond.html>
 
-http://datetime.perl.org
-
 =head1 SUPPORT
 
 Bugs may be submitted at L<https://github.com/houseabsolute/DateTime.pm/issues>.
@@ -187,8 +182,6 @@ Bugs may be submitted at L<https://github.com/houseabsolute/DateTime.pm/issues>.
 There is a mailing list available for users of this distribution,
 L<mailto:datetime@perl.org>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for DateTime can be found at L<https://github.com/houseabsolute/DateTime.pm>.
@@ -199,7 +192,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2003 - 2020 by Dave Rolsky.
+This software is Copyright (c) 2003 - 2021 by Dave Rolsky.
 
 This is free software, licensed under:
 
